@@ -25,6 +25,9 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         elif self.config[0]=="White":self.on_White_triggered()
         elif self.config[0]=="Red":self.on_Red_triggered()
         elif self.config[0]=="Green":self.on_Green_triggered()
+        if self.config[1]=="Auto":
+            self.on_actionAuto_Rotation_toggled( 1)
+            self.actionAuto_Rotation.setChecked(True)
         
     
     @pyqtSignature("")
@@ -271,21 +274,20 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         
     @pyqtSignature("bool")
     def on_actionAuto_Rotation_toggled(self, p0):
-        print "setting Autorotate"
         if p0:
+            self.config[1]="Auto"
             try : 
                 self.setAttribute(Qt.WA_Maemo5AutoOrientation, 1)
                 self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged );
-                print" Auto rotation on"
             except:print "could not autorotate on"
         else:
+            self.config[1]="Landscape"
             try : 
                 self.setAttribute(Qt.WA_Maemo5AutoOrientation, 0)
-                print "Auto rotation off"
             except: print "could not autorotate off"
+        self.writeConfig()    
     
     def orientationChanged(self):
-        print "orientation changed"
         screenGeometry=QApplication.desktop().screenGeometry();
         if screenGeometry.width() > screenGeometry.height():
             self.portrait=1
@@ -293,6 +295,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         else:
             self.portrait=0
             self.rotateDisplay()
+            
 
         
     @pyqtSignature("")
